#[repr(i32)]pub enum ErrorCode {
InternalServerErrorUnspecified = 0,
ParseFailed = 1,
ResolverNotFound = 2,
InvalidQuery = 3,
ValidationFailed = 4,
ResolverFailed = 5,
ResolverTimedOut = 6,
UpstreamFailed = 7,
Unauthenticated = 8,
Unauthorized = 9,
Cancelled = 10,
DeadlineExceeded = 11,
}Variants
InternalServerErrorUnspecified = 0
An unspecified error occurred.
ParseFailed = 1
The query contained features that do not exist
ResolverNotFound = 2
A resolver was required as part of running the dependency graph that could not be found.
InvalidQuery = 3
The query is invalid. All supplied features need to be rooted in the same top-level entity.
ValidationFailed = 4
A feature value did not match the expected schema
(e.g. incompatible type "int"; expected "str")
ResolverFailed = 5
The resolver for a feature errored.
ResolverTimedOut = 6
The resolver for a feature timed out.
UpstreamFailed = 7
A crash in a resolver that was to produce an input for the resolver crashed, and so the resolver could not run crashed, and so the resolver could not run.
Unauthenticated = 8
The request was submitted with an invalid authentication header.
The supplied credentials do not provide the right authorization to execute the request.
Cancelled = 10
The operation was cancelled, typically by the caller.
DeadlineExceeded = 11
The deadline expired before the operation could complete.
Implementations
Sourceimpl ErrorCode
impl ErrorCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.