pub struct DataFrameConstructor {
pub self_operand: Option<DataFrameIndex>,
pub function_name: String,
pub args: Option<PyList>,
pub kwargs: Option<PyDict>,
}Fields
self_operand: Option<DataFrameIndex>/ If present, this is a method called on self_operand.
/ Otherwise, it is a static method on the class itself.
function_name: String/ The name of the function to construct the dataframe object.
args: Option<PyList>/ Positional arguments passed to the function.
kwargs: Option<PyDict>/ Keyword arguments passed to the function.