pub struct DataFramePlan {
pub constructors: Vec<DataFrameConstructor>,
}Fields
constructors: Vec<DataFrameConstructor>/ A sequence of intermediate constructors used to build this plan. / Constructors can refer to earlier dataframes in the sequence. / / The last constructor is the output of the plan.