pub enum ExprForm {
Identifier(Identifier),
GetAttribute(Box<ExprGetAttribute>),
GetSubscript(Box<ExprGetSubscript>),
Call(Box<ExprCall>),
LiteralValue(ExprLiteral),
TypedIdentifier(TypedIdentifier),
}Expand description
Each expression has a form, which is one of the following.
These forms are deliberately purely syntactic - additional semantic information, like types, are dependent on the feature graph, which may therefore be out-of-date when decoding an expression message.
Consumers must always perform additional parsing and validation, so semantic information should not be stored in the proto message itself.
Variants
Identifier(Identifier)
GetAttribute(Box<ExprGetAttribute>)
GetSubscript(Box<ExprGetSubscript>)
Call(Box<ExprCall>)
LiteralValue(ExprLiteral)
TypedIdentifier(TypedIdentifier)
Implementations
Sourceimpl ExprForm
impl ExprForm
Sourcepub fn merge(
field: &mut Option<ExprForm>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<ExprForm>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.