pub enum Postprocessing {
UnderscoreExpr(LogicalExprNode),
LazyframeExpr(LogicalExprNode),
}Expand description
Applied to the results of running a resolver. Currently only enabled for SQL resolvers.
Variants
UnderscoreExpr(LogicalExprNode)
Column projection to apply to the resolver outputs – result should be a
struct or list
LazyframeExpr(LogicalExprNode)
LazyFrame table operation to apply on the SQL outputs
Implementations
Sourceimpl Postprocessing
impl Postprocessing
Sourcepub fn merge(
field: &mut Option<Postprocessing>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Postprocessing>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.