pub struct DatabaseSourceReference {
pub type: i32,
pub name: String,
}Fields
type: i32name: StringImplementations
Sourceimpl DatabaseSourceReference
impl DatabaseSourceReference
Sourcepub fn type(&self) -> DatabaseSourceType
pub fn type(&self) -> DatabaseSourceType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: DatabaseSourceType)
pub fn set_type(&mut self, value: DatabaseSourceType)
Sets type to the provided enum value.