pub struct FeatureSet {
pub name: String,
pub features: Vec<FeatureType>,
pub max_staleness_duration: Option<Duration>,
pub is_singleton: bool,
pub tags: Vec<String>,
pub owner: Option<String>,
pub doc: Option<String>,
pub etl_offline_to_online: Option<bool>,
pub class_path: Option<String>,
pub online_store_config: Option<String>,
}Fields
name: Stringfeatures: Vec<FeatureType>max_staleness_duration: Option<Duration>is_singleton: boolowner: Option<String>doc: Option<String>The docstring of the class on which the features are defined.
etl_offline_to_online: Option<bool>class_path: Option<String>online_store_config: Option<String>Implementations
Sourceimpl FeatureSet
impl FeatureSet
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn etl_offline_to_online(&self) -> bool
pub fn etl_offline_to_online(&self) -> bool
Returns the value of etl_offline_to_online, or the default value if etl_offline_to_online is unset.
Sourcepub fn class_path(&self) -> &str
pub fn class_path(&self) -> &str
Returns the value of class_path, or the default value if class_path is unset.
Sourcepub fn online_store_config(&self) -> &str
pub fn online_store_config(&self) -> &str
Returns the value of online_store_config, or the default value if online_store_config is unset.