pub struct Graph {
pub feature_sets: Vec<FeatureSet>,
pub resolvers: Vec<Resolver>,
pub stream_resolvers: Vec<StreamResolver>,
pub sink_resolvers: Vec<SinkResolver>,
pub database_sources: Vec<DatabaseSource>,
pub stream_sources: Vec<StreamSource>,
pub named_queries: Vec<NamedQuery>,
pub database_sources_v2: Vec<DatabaseSource>,
pub database_source_groups: Vec<DatabaseSourceGroup>,
pub stream_sources_v2: Vec<StreamSource>,
pub model_references: Vec<ModelReference>,
pub online_store_configs: Vec<OnlineStoreConfig>,
}Fields
feature_sets: Vec<FeatureSet>resolvers: Vec<Resolver>stream_resolvers: Vec<StreamResolver>sink_resolvers: Vec<SinkResolver>database_sources: Vec<DatabaseSource>👎Deprecated
database_sources is deprecated; see database_sources_v2
stream_sources: Vec<StreamSource>👎Deprecated
stream_sources is deprecated; see stream_sources_v2
named_queries: Vec<NamedQuery>database_sources_v2: Vec<DatabaseSource>database_source_groups: Vec<DatabaseSourceGroup>stream_sources_v2: Vec<StreamSource>model_references: Vec<ModelReference>online_store_configs: Vec<OnlineStoreConfig>Trait Implementations
Sourceimpl Message for Graph
impl Message for Graph
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for Graph