pub struct StreamSourceReference {
pub type: i32,
pub name: String,
}Fields
type: i32name: StringImplementations
Sourceimpl StreamSourceReference
impl StreamSourceReference
Sourcepub fn type(&self) -> StreamSourceType
pub fn type(&self) -> StreamSourceType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: StreamSourceType)
pub fn set_type(&mut self, value: StreamSourceType)
Sets type to the provided enum value.