pub struct DatabaseSourceReference {
pub source_type: String,
pub name: String,
}Expand description
Pointer to an underlying database source – used by native sql resolvers to identify which DB they are for
Fields
source_type: StringThe type of the database source – e.g. postgres, bigquery
name: StringThe (customer provided) name for the database source. The default source for the given type is represented by the empty string