pub struct ChalkGrpcClientBuilder { /* private fields */ }Expand description
Builder for ChalkGrpcClient.
Implementations
Sourceimpl ChalkGrpcClientBuilder
impl ChalkGrpcClientBuilder
pub fn client_id(self, id: impl Into<String>) -> Self
pub fn client_secret(self, secret: impl Into<String>) -> Self
pub fn api_server(self, url: impl Into<String>) -> Self
pub fn environment(self, env: impl Into<String>) -> Self
Sourcepub fn branch_id(self, id: impl Into<String>) -> Self
pub fn branch_id(self, id: impl Into<String>) -> Self
If specified, Chalk will route all requests from this client to the relevant branch.
Sourcepub fn deployment_tag(self, tag: impl Into<String>) -> Self
pub fn deployment_tag(self, tag: impl Into<String>) -> Self
Chalk can route queries to specific deployments using deployment tags.
Sourcepub fn query_server(self, url: impl Into<String>) -> Self
pub fn query_server(self, url: impl Into<String>) -> Self
Chalk routes performance-sensitive requests like online query directly to the query engine. Set this to override the automatically resolved query server URL.
Sourcepub async fn build(self) -> Result<ChalkGrpcClient>
pub async fn build(self) -> Result<ChalkGrpcClient>
Build the gRPC client, exchanging credentials for a token and establishing an HTTP/2 connection to the query engine.