Module http_client

Module http_client 

HTTP/REST client for the Chalk feature store.

ChalkClient is the main entry point for most users. It talks to the Chalk API over HTTP/JSON (for query, offline_query) and HTTP with Arrow IPC binary bodies (for query_bulk, upload_features).

Builder pattern

You construct a ChalkClient using the builder, which mirrors the config builder but also performs the initial token exchange:

use chalk_client::ChalkClient;

let client = ChalkClient::new()
    .client_id("my-client-id")
    .client_secret("my-secret")
    .environment("production")
    .build()
    .await?;

// Now use it:
// let response = client.query(inputs, outputs, options).await?;

Structs

BulkQueryResult
The result of a bulk (feather) query.
ChalkClient
An HTTP/REST client for the Chalk feature store.
ChalkClientBuilder
Builder for ChalkClient.