pub struct StreamResolver {Show 21 fields
pub fqn: String,
pub params: Vec<StreamResolverParam>,
pub outputs: Vec<ResolverOutput>,
pub explicit_schema: Option<ArrowType>,
pub keys: Vec<StreamKey>,
pub source: Option<StreamSourceReference>,
pub parse_info: Option<ParseInfo>,
pub mode: i32,
pub environments: Vec<String>,
pub timeout_duration: Option<Duration>,
pub timestamp_attribute_name: Option<String>,
pub owner: Option<String>,
pub doc: Option<String>,
pub machine_type: Option<String>,
pub function: Option<FunctionReference>,
pub source_v2: Option<StreamSourceReference>,
pub updates_materialized_aggregations: bool,
pub feature_expressions: HashMap<String, FeatureExpression>,
pub message_producer: Option<StreamResolverMessageProducerParsed>,
pub skip_online: bool,
pub skip_offline: bool,
}Fields
fqn: Stringparams: Vec<StreamResolverParam>outputs: Vec<ResolverOutput>explicit_schema: Option<ArrowType>keys: Vec<StreamKey>source: Option<StreamSourceReference>👎Deprecated
parse_info: Option<ParseInfo>mode: i32environments: Vec<String>timeout_duration: Option<Duration>timestamp_attribute_name: Option<String>owner: Option<String>doc: Option<String>machine_type: Option<String>function: Option<FunctionReference>source_v2: Option<StreamSourceReference>updates_materialized_aggregations: boolfeature_expressions: HashMap<String, FeatureExpression>Represents features computed as static projection expressions on an input message.
message_producer: Option<StreamResolverMessageProducerParsed>skip_online: boolSkip online persistence (no writes to Redis/DynamoDB/etc). Default: false Note: Only applies to native streaming (make_stream_resolver)
skip_offline: boolSkip offline persistence (no result bus publishing for offline storage). Default: false Note: Only applies to native streaming (make_stream_resolver)
Implementations
Sourceimpl StreamResolver
impl StreamResolver
Sourcepub fn mode(&self) -> WindowMode
pub fn mode(&self) -> WindowMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: WindowMode)
pub fn set_mode(&mut self, value: WindowMode)
Sets mode to the provided enum value.
Sourcepub fn timestamp_attribute_name(&self) -> &str
pub fn timestamp_attribute_name(&self) -> &str
Returns the value of timestamp_attribute_name, or the default value if timestamp_attribute_name is unset.
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn machine_type(&self) -> &str
pub fn machine_type(&self) -> &str
Returns the value of machine_type, or the default value if machine_type is unset.