pub struct WindowAggregation {Show 15 fields
pub namespace: String,
pub group_by: Vec<FeatureReference>,
pub bucket_duration: Option<Duration>,
pub aggregation: String,
pub aggregate_on: Option<FeatureReference>,
pub arrow_type: Option<ArrowType>,
pub filters: Vec<LogicalExprNode>,
pub backfill_resolver: Option<String>,
pub backfill_lookback_duration: Option<Duration>,
pub backfill_start_time: Option<Timestamp>,
pub continuous_resolver: Option<String>,
pub continuous_buffer_duration: Option<Duration>,
pub backfill_schedule: Option<String>,
pub bucket_start: Option<Timestamp>,
pub approx_top_k_arg_k: Option<i64>,
}Fields
namespace: Stringgroup_by: Vec<FeatureReference>bucket_duration: Option<Duration>aggregation: Stringaggregate_on: Option<FeatureReference>arrow_type: Option<ArrowType>filters: Vec<LogicalExprNode>backfill_resolver: Option<String>The resolver to use for back-filling the materialized aggregate. If not provided, the data will be back filled using the resolver that would run for an offline query.
backfill_lookback_duration: Option<Duration>The amount of time before the start of the previous backfill to consider when running the backfill resolver. Set this parameter to the be equal to the latest arriving data in the backfill window.
backfill_start_time: Option<Timestamp>The time at which to start back filling the materialized aggregate.
If not provided, the backfill consider the earliest available data returned
by the backfill_resolver.
continuous_resolver: Option<String>The resolver to use for continuous updates to the materialized aggregate. If not provided, the data will be updated using the resolver that would run for an online query.
continuous_buffer_duration: Option<Duration>The period for which to use the continuous resolver, instead of relying upon the last backfill. If not provided, and a continuous resolver is provided, this will be set to backfill_lookback_duration.
backfill_schedule: Option<String>A crontab or duration string to specify the schedule for back filling the materialized aggregate.
bucket_start: Option<Timestamp>The lower bound of the first bucket. All buckets are aligned to this time.
approx_top_k_arg_k: Option<i64>The ‘k’ arg of approx_top_k.
Implementations
Sourceimpl WindowAggregation
impl WindowAggregation
Sourcepub fn backfill_resolver(&self) -> &str
pub fn backfill_resolver(&self) -> &str
Returns the value of backfill_resolver, or the default value if backfill_resolver is unset.
Sourcepub fn continuous_resolver(&self) -> &str
pub fn continuous_resolver(&self) -> &str
Returns the value of continuous_resolver, or the default value if continuous_resolver is unset.
Sourcepub fn backfill_schedule(&self) -> &str
pub fn backfill_schedule(&self) -> &str
Returns the value of backfill_schedule, or the default value if backfill_schedule is unset.
Sourcepub fn approx_top_k_arg_k(&self) -> i64
pub fn approx_top_k_arg_k(&self) -> i64
Returns the value of approx_top_k_arg_k, or the default value if approx_top_k_arg_k is unset.