DatabaseSourceReference

Struct DatabaseSourceReference 

pub struct DatabaseSourceReference {
    pub source_type: String,
    pub name: String,
}
Pointer to an underlying database source – used by native sql resolvers to identify which DB they are for

Fields

source_type: String

The type of the database source – e.g. postgres, bigquery

name: String

The (customer provided) name for the database source. The default source for the given type is represented by the empty string